AppTextStyles class abstract

AppTextStyles provides a set of predefined text styles for consistent typography across the app.

Constructors

AppTextStyles()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

f10w400gray TextStyle
Regular 10pt text style with normal weight and gray color.
getter/setter pair
f10w400Success600 TextStyle
Regular 10pt text style with normal weight and success shade 600.
getter/setter pair
f10w800Gray900 TextStyle
Extra-bold 10pt text style with gray shade 900.
final
f12w400Error500 TextStyle
Regular 12pt text style with normal weight and error shade 500.
final
f12w400Gray400 TextStyle
Regular 12pt text style with normal weight and gray shade 400.
final
f12w400Gray500 TextStyle
Regular 12pt text style with normal weight and gray shade 500.
final
f12w400Gray600 TextStyle
Regular 12pt text style with normal weight and gray shade 600.
final
f12w500Gray400 TextStyle
Medium 12pt text style with medium weight and gray shade 400.
final
f12w500Gray900 TextStyle
Medium 12pt text style with medium weight and gray shade 900.
final
f12w700Gray700 TextStyle
Bold 12pt text style with gray shade 700.
final
f14w200Gray200 TextStyle
Regular 14pt text style with light weight and gray shade 200.
final
f14w400Gray400 TextStyle
Regular 14pt text style with normal weight and gray shade 400.
final
f14w400Gray500 TextStyle
Regular 14pt text style with normal weight and gray shade 500.
final
f14w400Gray700 TextStyle
Regular 14pt text style with normal weight and gray shade 700.
final
f14w400Gray800 TextStyle
Regular 14pt text style with normal weight and gray shade 800.
final
f14w400Gray900 TextStyle
Regular 14pt text style with normal weight and gray shade 900.
final
f14w400Warning500 TextStyle
Regular 14pt text style with normal weight and warning shade 500.
final
f14w500Gray900 TextStyle
Bold 14pt text style with gray shade 700.
final
f14w700Gray400 TextStyle
Bold 14pt text style with gray shade 400.
final
f16w400Gray200 TextStyle
Regular 16pt text style with normal weight and gray shade 200.
final
f16w500Gray700 TextStyle
Medium 16pt text style with medium weight and gray shade 700.
final
f16w500Gray900 TextStyle
Medium 16pt text style with medium weight and gray shade 900.
final
f16w700Gray700 TextStyle
Bold 16pt text style with gray shade 700.
final
f18w400Gray800 TextStyle
Regular 18pt text style with normal weight and gray shade 800.
final
f18w500Gray900 TextStyle
Medium 18pt text style with medium weight and gray shade 900.
final

Constants

f8w400gray → const TextStyle
Regular 8pt text style with normal weight and gray color.
f8w700gray → const TextStyle
Bold 8pt text style with gray color.
f10w600Gray → const TextStyle
Semi-bold 10pt text style with gray color.
f10w600White → const TextStyle
Semi-bold 10pt text style with white color.
f12w400 → const TextStyle
Regular 12pt text style with normal weight.
f12w400Blue → const TextStyle
Regular 12pt text style with normal weight and blue color.
f12w400Error → const TextStyle
Regular 12pt text style with normal weight and error color.
f12w400Gray → const TextStyle
Regular 12pt text style with normal weight and gray color.
f12w400Primary → const TextStyle
Regular 12pt text style with normal weight and primary color.
f12w400White → const TextStyle
Regular 12pt text style with normal weight and white color.
f12w500 → const TextStyle
Medium 12pt text style with medium weight.
f12w500error → const TextStyle
Medium 12pt text style with medium weight and error color.
f12w500Gray → const TextStyle
Medium 12pt text style with medium weight and gray color.
f12w500success → const TextStyle
Medium 12pt text style with medium weight and success color.
f12w700 → const TextStyle
Bold 12pt text style with black color.
f12w700blue → const TextStyle
Bold 12pt text style with blue color.
f12w700Error → const TextStyle
Bold 12pt text style with error color.
f12w700Gray → const TextStyle
Bold 12pt text style with gray color.
f12w700Primary → const TextStyle
Bold 12pt text style with primary color.
f12w700success → const TextStyle
Bold 12pt text style with success color.
f12w700Warning → const TextStyle
Bold 12pt text style with warning color.
f12w700White → const TextStyle
Bold 12pt text style with white color.
f12w900 → const TextStyle
Extra-bold 12pt text style with black color.
f14w400 → const TextStyle
Regular 14pt text style with normal weight.
f14w400Error → const TextStyle
Regular 14pt text style with normal weight and error color.
f14w400Gray → const TextStyle
Regular 14pt text style with normal weight and gray color.
f14w400Primary → const TextStyle
Regular 14pt text style with normal weight and primary color.
f14w400Success → const TextStyle
Regular 14pt text style with normal weight and success color.
f14w400Warning → const TextStyle
Regular 14pt text style with normal weight and warning color.
f14w400White → const TextStyle
Regular 14pt text style with normal weight and white color.
f14w500 → const TextStyle
Medium 14pt text style with medium weight.
f14w500Gray → const TextStyle
Medium 14pt text style with medium weight and gray color.
f14w500Gray700 → const TextStyle
Medium 14pt text style with medium weight and gray shade 700.
f14w500Primary → const TextStyle
Medium 14pt text style with medium weight and primary color.
f14w500White → const TextStyle
Medium 14pt text style with medium weight and white color.
f14w700 → const TextStyle
Bold 14pt text style with black color.
f14w700Blue → const TextStyle
Bold 14pt text style with blue color.
f14w700Gray → const TextStyle
Bold 14pt text style with gray color.
f14w700Primary → const TextStyle
Bold 14pt text style with primary color.
f14w700White → const TextStyle
Bold 14pt text style with white color.
f14w900 → const TextStyle
Extra-bold 14pt text style with black color.
f16w400 → const TextStyle
Regular 16pt text style with normal weight.
f16w400Gray → const TextStyle
Regular 16pt text style with normal weight and gray color.
f16w400Primary → const TextStyle
Regular 16pt text style with normal weight and primary color.
f16w400White → const TextStyle
Regular 16pt text style with normal weight and white color.
f16w400white → const TextStyle
Regular 16pt text style with normal weight and white color.
f16w500 → const TextStyle
Medium 16pt text style with medium weight.
f16w500error → const TextStyle
Medium 16pt text style with medium weight and error color.
f16w500Gray → const TextStyle
Medium 16pt text style with medium weight and gray color.
f16w500Primary → const TextStyle
Medium 16pt text style with medium weight and primary color.
f16w500White → const TextStyle
Medium 16pt text style with medium weight and white color.
f16w700 → const TextStyle
Bold 16pt text style with black color.
f16w700BaseBlack → const TextStyle
Bold 16pt text style with base black color.
f16w700Bold → const TextStyle
Bold 16pt text style with black color.
f16w700Gray → const TextStyle
Bold 16pt text style with gray color.
f16w900 → const TextStyle
Extra-bold 16pt text style with black color.
f18w400 → const TextStyle
Regular 18pt text style with normal weight.
f18w400blue → const TextStyle
Regular 18pt text style with normal weight and blue color.
f18w500 → const TextStyle
Medium 18pt text style with medium weight.
f18w500Primary → const TextStyle
Medium 18pt text style with medium weight and primary color.
f18w700 → const TextStyle
Bold 18pt text style with black color.
f18w700Primary → const TextStyle
Bold 18pt text style with primary color.
f18w900 → const TextStyle
Extra-bold 18pt text style with black color.
f20w400 → const TextStyle
Regular 20pt text style with normal weight.
f20w500 → const TextStyle
Medium 20pt text style with medium weight.
f20w700 → const TextStyle
Bold 20pt text style with black color.
f20w900 → const TextStyle
Extra-bold 20pt text style with black color.
f24w400 → const TextStyle
Regular 24pt text style with normal weight.
f24w500 → const TextStyle
Medium 24pt text style with medium weight.
f24w700 → const TextStyle
Bold 24pt text style with black color.
f24w700Primary → const TextStyle
Bold 24pt text style with primary color.
f24w900 → const TextStyle
Extra-bold 24pt text style with black color.
f36w700 → const TextStyle
Bold 26pt text style with black color.
f40w700Primary → const TextStyle
Bold 40pt text style with primary color.