f12w400Gray400 property
Regular 12pt text style with normal weight and gray shade 400.
Implementation
static final f12w400Gray400 = TextStyle(
fontSize: 12,
color: AppColors.gray.shade400,
fontWeight: FontWeight.w400,
);
Regular 12pt text style with normal weight and gray shade 400.
static final f12w400Gray400 = TextStyle(
fontSize: 12,
color: AppColors.gray.shade400,
fontWeight: FontWeight.w400,
);