f16w500Gray900 property
Medium 16pt text style with medium weight and gray shade 900.
Implementation
static final f16w500Gray900 = TextStyle(
fontSize: 16,
color: AppColors.gray.shade900,
fontWeight: FontWeight.w500,
);
Medium 16pt text style with medium weight and gray shade 900.
static final f16w500Gray900 = TextStyle(
fontSize: 16,
color: AppColors.gray.shade900,
fontWeight: FontWeight.w500,
);