height method

Widget height({
  1. Widget? child,
  2. Key? key,
})

Returns a SizedBox with the height set to the value of this num.

Optionally, a child widget can be passed along with an optional key.

Implementation

Widget height({Widget? child, Key? key}) =>
    SizedBox(key: key, height: toDouble(), child: child);