NinjaUiStatusColors class abstract

A utility class for managing status colors.

Constructors

NinjaUiStatusColors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

addColorsMap Map<String, Color>
Adds additional colors to the existing status colors map.
no getter
statusColors Map<String, Color>
Gets the current status colors map.
no setter
statusColorsMap Map<String, Color>
Sets the status colors map.
no getter