NinjaUiWidgetExtension extension

Extension on Widget to provide convenient methods for wrapping widgets with Flexible, Expanded, Center, and debug widgets.

on

Methods

center({Key? key}) Widget

Available on Widget, provided by the NinjaUiWidgetExtension extension

Wraps the widget in a Center widget.
debugBorder({Key? key, Color color = Colors.red, double thickness = 1}) Widget

Available on Widget, provided by the NinjaUiWidgetExtension extension

Wraps the widget in a Container with a debug border.
debugContainer({Key? key, Color color = Colors.red}) Widget

Available on Widget, provided by the NinjaUiWidgetExtension extension

Wraps the widget in a Container with a debug color.
expanded({int flex = 1, Key? key}) Widget

Available on Widget, provided by the NinjaUiWidgetExtension extension

Wraps the widget in an Expanded widget.
flexible({FlexFit fit = FlexFit.loose, int flex = 1, Key? key}) Widget

Available on Widget, provided by the NinjaUiWidgetExtension extension

Wraps the widget in a Flexible widget.