center method

Widget center({
  1. Key? key,
})

Wraps the widget in a Center widget.

The key parameter is optional and can be used to provide a Key for the Center widget.

Example usage:

Container().center();

Implementation

Widget center({Key? key}) => Center(key: key, child: this);