expanded method

Widget expanded({
  1. int flex = 1,
  2. Key? key,
})

Wraps the widget in an Expanded widget.

The flex parameter defines the flex factor, defaulting to 1.

The key parameter is optional and can be used to provide a Key for the Expanded widget.

Example usage:

Container().expanded(flex: 3);

Implementation

Widget expanded({int flex = 1, Key? key}) =>
    Expanded(flex: flex, key: key, child: this);