PrimaryOutlinedButton class

A customizable outlined button widget with optional leading and trailing widgets.

The PrimaryOutlinedButton can be used to create a button with a label, optional leading and trailing widgets, and customizable colors and styles.

The button can be in a loading state, and it supports both active and disabled states.

The onTap callback is triggered when the button is pressed.

Inheritance
Available extensions

Constructors

PrimaryOutlinedButton({Key? key, Color? activeBackgroundColor, Color? disabledBackgroundColor, Color? activeForegroundColor, Color? disabledForegroundColor, TextStyle? activeTextStyle, TextStyle? disabledTextStyle, Widget? leading, Widget? trailing, double gap = 8, bool isLoading = false, VoidCallback? onTap, double height = 48, double radius = 8, required String label, double? width})
Creates a PrimaryOutlinedButton.
const

Properties

activeBackgroundColor Color?
The background color when the button is active.
final
activeForegroundColor Color?
The foreground color when the button is active.
final
activeTextStyle TextStyle?
The text style when the button is active.
final
disabledBackgroundColor Color?
The background color when the button is disabled.
final
disabledForegroundColor Color?
The foreground color when the button is disabled.
final
disabledTextStyle TextStyle?
The text style when the button is disabled.
final
gap double
The gap between the leading/trailing widget and the label.
final
hashCode int
The hash code for this object.
no setterinherited
height double
The height of the button.
final
isLoading bool
Whether the button is in a loading state.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
The label text of the button.
final
leading Widget?
An optional widget to display before the label.
final
onTap VoidCallback?
The callback to be called when the button is tapped.
final
radius double
The border radius of the button.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trailing Widget?
An optional widget to display after the label.
final
width double?
The width of the button.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
center({Key? key}) Widget

Available on Widget, provided by the NinjaUiWidgetExtension extension

Wraps the widget in a Center widget.
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugBorder({Key? key, Color color = Colors.red, double thickness = 1}) Widget

Available on Widget, provided by the NinjaUiWidgetExtension extension

Wraps the widget in a Container with a debug border.
debugContainer({Key? key, Color color = Colors.red}) Widget

Available on Widget, provided by the NinjaUiWidgetExtension extension

Wraps the widget in a Container with a debug color.
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1, Key? key}) Widget

Available on Widget, provided by the NinjaUiWidgetExtension extension

Wraps the widget in an Expanded widget.
flexible({FlexFit fit = FlexFit.loose, int flex = 1, Key? key}) Widget

Available on Widget, provided by the NinjaUiWidgetExtension extension

Wraps the widget in a Flexible widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
small({double height = 34, double radius = 4, double? fontSize}) Widget
Creates a smaller version of the button.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited