NinjaUi class
A widget that displays a loading indicator, adapting to the platform.
The NinjaUi can display either a CupertinoActivityIndicator for iOS or a CircularProgressIndicator for other platforms. The size, color, and optional stroke width can be customized.
- Inheritance
- Available extensions
Constructors
Properties
- color → Color
-
The color of the loader.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
The size of the loader.
final
- strokeWidth → double?
-
The stroke width of the loader, applicable for non-iOS platforms.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
center(
{Key? key}) → Widget -
Available on Widget, provided by the NinjaUiWidgetExtension extension
Wraps the widget in a Center widget. -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugBorder(
{Key? key, Color color = Colors.red, double thickness = 1}) → Widget -
Available on Widget, provided by the NinjaUiWidgetExtension extension
Wraps the widget in a Container with a debug border. -
debugContainer(
{Key? key, Color color = Colors.red}) → Widget -
Available on Widget, provided by the NinjaUiWidgetExtension extension
Wraps the widget in a Container with a debug color. -
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expanded(
{int flex = 1, Key? key}) → Widget -
Available on Widget, provided by the NinjaUiWidgetExtension extension
Wraps the widget in an Expanded widget. -
flexible(
{FlexFit fit = FlexFit.loose, int flex = 1, Key? key}) → Widget -
Available on Widget, provided by the NinjaUiWidgetExtension extension
Wraps the widget in a Flexible widget. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultLoader(
) → Widget - Provides a default loader with a predefined size and color.