NinjaUiNumExtension extension
Extension on num to provide convenient methods for setting the width of a widget.
- on
Methods
-
height(
{Widget? child, Key? key}) → Widget -
Available on num, provided by the NinjaUiNumExtension extension
Returns a SizedBox with the height set to the value of this num. -
square(
{Widget? child, Key? key}) → Widget -
Available on num, provided by the NinjaUiNumExtension extension
Returns a square SizedBox with dimensions equal to the value of this num. -
width(
{Widget? child, Key? key}) → Widget -
Available on num, provided by the NinjaUiNumExtension extension
Returns a SizedBox with the width set to the value of this num.