debugContainer method
Wraps the widget in a Container with a debug color.
The key parameter is optional and can be used to provide a
Key for the Container.
The color parameter specifies the color of the debug container,
defaulting to red.
Example usage:
Text('Debug').debugContainer();
Implementation
Widget debugContainer({Key? key, Color color = Colors.red}) =>
Container(key: key, color: color, child: this);