PrimaryImageButton class
A customizable button widget that displays an image and supports loading state.
The PrimaryImageButton can be configured with different colors for active and disabled states,
and can display a loading indicator when needed.
The button's appearance and behavior can be customized using the provided parameters.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PrimaryImageButton
- Available extensions
Constructors
- PrimaryImageButton({Key? key, Color? activeBackgroundColor, Color? disabledBackgroundColor, Color? activeForegroundColor, Color? disabledForegroundColor, bool isLoading = false, VoidCallback? onTap, double buttonHeight = 34, double? width, double radius = 4, required String imagePath})
-
Creates a PrimaryImageButton.
const
Properties
- activeBackgroundColor → Color?
-
The background color when the button is active.
final
- activeForegroundColor → Color?
-
The foreground color when the button is active.
final
-
The height of the button.
final
- disabledBackgroundColor → Color?
-
The background color when the button is disabled.
final
- disabledForegroundColor → Color?
-
The foreground color when the button is disabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imagePath → String
-
The path to the image asset to display on the button.
final
- isLoading → bool
-
Whether the button is in a loading state.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTap → VoidCallback?
-
The callback to be invoked when the button is tapped.
If null, the button is considered disabled.
final
- radius → double
-
The border radius of the button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
The width of the button. If null, the button will size itself to fit its content.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
center(
{Key? key}) → Widget -
Available on Widget, provided by the NinjaUiWidgetExtension extension
Wraps the widget in a Center widget. -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugBorder(
{Key? key, Color color = Colors.red, double thickness = 1}) → Widget -
Available on Widget, provided by the NinjaUiWidgetExtension extension
Wraps the widget in a Container with a debug border. -
debugContainer(
{Key? key, Color color = Colors.red}) → Widget -
Available on Widget, provided by the NinjaUiWidgetExtension extension
Wraps the widget in a Container with a debug color. -
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expanded(
{int flex = 1, Key? key}) → Widget -
Available on Widget, provided by the NinjaUiWidgetExtension extension
Wraps the widget in an Expanded widget. -
flexible(
{FlexFit fit = FlexFit.loose, int flex = 1, Key? key}) → Widget -
Available on Widget, provided by the NinjaUiWidgetExtension extension
Wraps the widget in a Flexible widget. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited